/* Copyright (c) 1996 University of Utah.  All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for NON-COMMERCIAL purposes and without fee is
 * hereby granted provided that this copyright notice appears in all
 * copies.
 *
 * See http://www.cs.utah.edu/~hamlet for more educational resources.
 *
 * The University of Utah MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT
 * THE SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR
 * NON-INFRINGEMENT. The University of Utah SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 */

/* 
<applet
        code="hamlet.AppButton.class" 
	name="Cannon.Cannon" 
	codebase=".."
	width=150 height=25
	align=absbottom>
        <param name=LABEL value="Open Cannon Window">
        
        If you can read this, you don't need glasses.  But you do <br>
        need a Java-compatible browser.<br>
</applet>
*/


/*      FileName:       cannonBall.java
 *      Written by:     Brandon Harvey
 *      Date:           July 1996
 *
 *      Modified by:    Elizabeth Odekirk
 *      Date:           October 1996
 *      Changes:	Made some minor changes in format.  Added time to 
 *			display.  On resize, no longer deletes old plots.
 */ 
package Cannon;

import java.awt.*;
import hamlet.*;
import Cannon.*;

public class Cannon extends AppFrame  {
  
    //  Interface components
    cannonControls	northPanel;
    Panel               westPanel;
    cannonPanel	        centerPanel;

    
public Cannon() {
    setTitle("Cannon");
    setLayout( new BorderLayout( 10,10 ) );

    
    //  set up the western set of buttons
    westPanel = new Panel();
    westPanel.setLayout( new GridLayout( 8, 1 ) );
    westPanel.add( "Fire", new Button("Fire") );
    westPanel.add( "Halt", new Button("Halt") );

    add("North", northPanel = new cannonControls() );
    add("West", westPanel );
    validate();
    add("Center", centerPanel = new cannonPanel() );
    centerPanel.controlPanel = northPanel;
	validate();
    setUpHelp();
  }

  
/* Can probably take most of this out of the lesson */
public void setUpHelp() {
  helpText =
      "This applet demonstrates the trajectory of a ballistic\n"	+
      "projectile by drawing an arc in the air.  It is based on the\n"	+
      "discussion in Chapter 7 of \"Introduction to Scientific\n"	+
      "Programming\" by Joseph L. Zachary.\n\n"				+ 
      //								//
      "File Menu\n"							+
      "   + Reset:  Returns to the default plot region\n"		+
      "   + Refresh: Refreshes the applet\n"				+
      "   + Hide:  Removes the applet from the display\n"		+
      "   + Quit:  Terminates the applet\n\n"				+
      //								//
      "Help Menu\n"							+
      "   + With Applet:  Displays this help dialog\n\n"		+
      //								//
      "Buttons\n"							+
      "   + Fire: Fires the cannon ball, beginning a new trajectory\n"	+
      "     on the graph using the values from the input fields\n"	+
      "   + Halt: Halts the cannon ball's trajectory\n\n"		+
      //								//
      "Input Fields\n"							+
      "   + Velocity: The initial velocity of the cannon ball as it\n"	+
      "     is fired, in meters/second. A higher velocity will make\n"	+
      "     the ball go further.\n"					+
      "   + Firing Angle: The angle of the cannon which is firing the\n"+
      "     cannon ball, in degrees from the x-axis.  A 45 degree \n"   +
      "     angle would look like: / .  A 90 degree angle would look\n" +
      "     like: | .\n"						+
      "   + Gravity: This is the effect of gravity on the cannon \n"    +
      "     ball, in meters/second^2.  Earth's gravity is \n"		+
      "     9.8 m/sec^2, which is the initial gravity field setting.\n\n"+
      //								//
      "Display\n"							+
      "   + Graph: This shows the trajectory of the cannon ball.  \n"	+
      "     The x-axis and y-axis are in meters.\n"			+  
      "   + Altitude: Keeps track at each moment in time of the \n"	+
      "     height of the cannon ball.  (Current y position).\n"	+
      "   + Distance: Keeps track at each moment in time of the \n"	+
      "     distance traveled by the cannon ball. (Current x position)\n"+
      "   + Time: Displays the current time.\n"				+
      "";
}

public void reset() {
  centerPanel.reset();
}

public Dimension preferredSize() {
	return new Dimension( 625, 350 );
}
   
protected void handleMessage( String msg ) {
    if ( msg.equals("Fire") )
        centerPanel.go();
    else if ( msg.equals("Reset") )
        centerPanel.reset();
    else if ( msg.equals("Fire1") ) {
        northPanel.gunAngle.setIntText(45);
	northPanel.velocity.setIntText(100);
        centerPanel.go();
    }
    else if ( msg.equals("Fire2") ) {
        northPanel.gunAngle.setIntText(35);
	northPanel.velocity.setIntText(150);
        centerPanel.go();
    }
    else if ( msg.equals("Fire3") ) {
        northPanel.gunAngle.setIntText(75);
	northPanel.velocity.setIntText(60);
        centerPanel.go();
    }
}
  
public boolean action(Event evt, Object arg) {

    if ( super.action( evt, arg ) )
	return true;
    
    if ( evt.target instanceof Button ) {
	if ( "Fire".equals(arg) ) {
	    
	    // if there's a ball in the air, ignore the command
	    if ( centerPanel.animatorThread == null ) {
     		//getAppletContext().showStatus("FIRE!");
     		centerPanel.go();
	    }
	}
	if ( "Halt".equals(arg) ) {
	    //getAppletContext().showStatus("Bang.");
	    centerPanel.halt();
	}
	else if ( "Reset".equals(arg) ) {
	    //getAppletContext().showStatus("CannonBall Carnage");
	    centerPanel.reset();
	}
	return true;
    }  else return false;
}

}


